pyLBM.Domain
============

.. currentmodule:: pyLBM

.. autoclass:: Domain

   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Domain.check_dictionary
         Domain.construct_mpi_topology
         Domain.create_coords
         Domain.get_bounds
         Domain.get_bounds_halo
         Domain.list_of_labels
         Domain.visualize



   

   .. HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
      .. autosummary::
         :toctree:
      
         Domain.shape_halo
         Domain.shape_in
         Domain.valin
         Domain.valout
         Domain.x
         Domain.x_halo
         Domain.y
         Domain.y_halo
         Domain.z
         Domain.z_halo

